import { BasicEvent } from "@skeldjs/events";
import { ProtectPlayerMessage } from "@skeldjs/protocol";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player (who is a guardian angel) protects another player.
 *
 * Due to technical limitations, this event cannot be  reverted without advanced
 * "breaking game", therefore it is out of scope of a single `.revert()` function.
 * However, see {@link PlayerCheckProtectEvent} to see about canceling a protection
 * before it happens if you are the host.
 */
export declare class PlayerProtectEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: ProtectPlayerMessage | undefined;
    /**
     * The player that was protected.
     */
    readonly target: PlayerData<RoomType>;
    /**
     * The duration, in seconds, for how long the player is protected for.
     */
    readonly duration: number;
    static eventName: "player.protect";
    eventName: "player.protect";
    constructor(room: RoomType, player: PlayerData<RoomType>, message: ProtectPlayerMessage | undefined, 
    /**
     * The player that was protected.
     */
    target: PlayerData<RoomType>, 
    /**
     * The duration, in seconds, for how long the player is protected for.
     */
    duration: number);
}
