import { BasicEvent } from "@skeldjs/events";
import { SetNameplateMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player has their player nameplate updated.
 */
export declare class PlayerSetNameplateEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetNameplateMessage | undefined;
    /**
     * The nameplate that the player had before.
     */
    readonly oldNameplateId: string;
    /**
     * The new nameplate that the player has.
     */
    readonly newNameplateId: string;
    static eventName: "player.setnameplate";
    eventName: "player.setnameplate";
    private _alteredNameplateId;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetNameplateMessage | undefined, 
    /**
     * The nameplate that the player had before.
     */
    oldNameplateId: string, 
    /**
     * The new nameplate that the player has.
     */
    newNameplateId: string);
    /**
     * The altered nameplate that the player will have set instead, if changed.
     */
    get alteredNameplateId(): string;
    /**
     * Revert the player's nameplate back to their old nameplate.
     */
    revert(): void;
    /**
     * Change the nameplate that the player had set.
     * @param nameplate The nameplate to set.
     */
    setNameplate(nameplate: string): void;
}
