import { BasicEvent } from "@skeldjs/events";
import { SetRoleMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { BaseRole } from "../../roles";
/**
 * Emitted when a player has their player role updated.
 */
export declare class PlayerSetRoleEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetRoleMessage | undefined;
    /**
     * The role that the player had before, if any.
     */
    readonly oldRole: typeof BaseRole;
    /**
     * The new role that the player has, if any.
     */
    readonly newRole: typeof BaseRole;
    static eventName: "player.setrole";
    eventName: "player.setrole";
    private _alteredRole;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetRoleMessage | undefined, 
    /**
     * The role that the player had before, if any.
     */
    oldRole: typeof BaseRole, 
    /**
     * The new role that the player has, if any.
     */
    newRole: typeof BaseRole);
    /**
     * The altered role that the player will have set instead, if changed.
     */
    get alteredRole(): typeof BaseRole;
    /**
     * Revert the player's role back to their old role.
     */
    revert(): void;
    /**
     * Change the role that the player had set, or completely remove it altogether.
     * @param role The role to set.
     */
    setRole(roleCtr: typeof BaseRole): void;
}
