import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { Hostable, PlayerDataResolvable } from "../Hostable";
import { MovingPlatformPlayerUpdateEvent } from "../events";
import { SystemStatusEvents } from "./events";
export interface MovingPlatformSystemData {
    useId: number;
    target: PlayerData | undefined;
    side: MovingPlatformSide;
}
export declare enum MovingPlatformSide {
    Right = 0,
    Left = 1
}
export declare type MovingPlatformSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[MovingPlatformPlayerUpdateEvent<RoomType>]>;
/**
 * Represents a system for doors that must be manually opened.
 *
 * See {@link MovingPlatformSystemEvents} for events to listen to.
 */
export declare class MovingPlatformSystem<RoomType extends Hostable = Hostable> extends SystemStatus<MovingPlatformSystemData, MovingPlatformSystemEvents, RoomType> implements MovingPlatformSystemData {
    useId: number;
    target: PlayerData<RoomType> | undefined;
    side: MovingPlatformSide;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | MovingPlatformSystemData);
    /**
     * The opposite side of the moving platform to move in.
     */
    get oppositeSide(): MovingPlatformSide;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    private _setTarget;
    /**
     * Update the target of the moving platform.
     * @param player The player to set.
     * @param side The direction to move the moving platform in.
     */
    setTarget(player: PlayerDataResolvable, side: MovingPlatformSide, sendRpc: boolean): Promise<void>;
    /**
     * Get on the moving platform as the client's player.
     */
    getOn(): Promise<void>;
    setSide(side: MovingPlatformSide): void;
}
